@@ -1,9 +1,7 @@
 #!/usr/bin/perl
-
 #
-# $Id: ipv4-flags.pl,v 1.1.2.1 2006/03/11 19:21:29 gomor Exp $
+# $Id: ipv4-flags.pl,v 1.2.2.1 2006/06/04 13:23:13 gomor Exp $
 #
-
 use strict;
 use warnings;
 
@@ -11,10 +9,10 @@ use Getopt::Std;
 my %opts;
 getopts('i:I:p:d:v', \%opts);
 
-die "Usage: send-syn.pl -i dstIp -p dstPort [-I srcIp] [-d device] [-v]\n"
+die "Usage: $0 -i dstIp -p dstPort [-I srcIp] [-d device] [-v]\n"
    unless $opts{i} && $opts{p};
 
-use Net::Pkt;
+use Net::Packet;
 
 $Env->dev($opts{d}) if $opts{d};
 $Env->ip ($opts{I}) if $opts{I};
